import React from 'react';
import { TextInputProps } from 'react-native-paper';
import { TextInputMaskProps } from 'react-native-masked-text';
/**
 * Properties for the {@link CrossEditor} component. Supports masking through {@link maskProps}. This allows getting the masked value.
 *
 * The `onChangeText` event will isntead export the raw value.
 *
 * Inherits react-native-paper {@link https://callstack.github.io/react-native-paper/text-input.html TextInputProps}
 */
export interface ICrossEditorProps extends TextInputProps {
    /**
     * Text for floating label
     * https://callstack.github.io/react-native-paper/text-input.html
     */
    label: string;
    /**
     * `True` to use error styling
     * https://callstack.github.io/react-native-paper/text-input.html
     */
    error?: boolean | undefined;
    /**
     * Visual appearence. Default value is 'outlined'
     *
     * https://callstack.github.io/react-native-paper/text-input.html
     */
    mode?: 'flat' | 'outlined' | undefined;
    /**
     * Allows masking the input.
     *
     * https://github.com/benhurott/react-native-masked-text
     *
     * @example
     * <CrossEditor
     *   label='Mobile'
     *   maskProps={{ type: 'cel-phone' }} />
     */
    maskProps?: TextInputMaskProps | undefined;
}
/**
 * A text input supporting mask through {@see ICrossEditorProps.maskProps}.
 *
 * When using mask the raw value will be exported in the `onChangeText` event, not the masked value.
 *
 * Default {@see ICrossEditorProps.mode mode} is 'outlined'.
 *
 * Props are {@see ICrossEditorProps}
 *
 *
 * @example
 * <CrossEditor
 *   label='Mobile'
 *   maskProps={{ type: 'cel-phone' }} />
 */
export declare class CrossEditor extends React.Component<ICrossEditorProps> {
    constructor(props: ICrossEditorProps);
    render(): JSX.Element;
}
export default CrossEditor;
//# sourceMappingURL=CrossEditor.d.ts.map