import React from 'react';
import { TextProps } from 'react-native';
/**
 * Properties for the {@link CrossLabel} component. Control component type using {@link isTitle}, {@link isCaption},
 * {@link isHeadline}, {@link isSubheading} and {@link isParagraph}.
 *
 * Create an URL link using {@link onPressUrlTarget} and customize color using {@link linkColor}.
 *
 * Inherits react-native Text's {@link https://facebook.github.io/react-native/docs/text.html#props TextProps}
 */
export interface ICrossLabelProps extends TextProps {
    /**
     * An url to open when user clicks the label. Styles the label as a clickable "link"
     */
    onPressUrlTarget?: string;
    /**
     * Optional color for the link. Default is 'blue'. See also {@link onPressUrlTarget}
     */
    linkColor?: string | undefined;
    /**
     * Displays text as a {@link https://callstack.github.io/react-native-paper/headline.html react-native paper Headline component}
     */
    isHeadline?: boolean | undefined;
    /**
     * Displays text as a {@link https://callstack.github.io/react-native-paper/title.html react-native paper Title component}
     */
    isTitle?: boolean | undefined;
    /**
     * Displays text as a {@link https://callstack.github.io/react-native-paper/subheading.html react-native paper Subheading component}
     */
    isSubheading?: boolean | undefined;
    /**
     * Displays text as a {@link https://callstack.github.io/react-native-paper/paragraph.html react-native paper Paragraph component}
     */
    isParagraph?: boolean | undefined;
    /**
     * Displays text as a {@link https://callstack.github.io/react-native-paper/caption.html react-native paper Caption component}
     */
    isCaption?: boolean | undefined;
}
/**
 * Wrapper for {@link https://callstack.github.io/react-native-paper/text.html react-native-paper Text} component
 * that displays as a clickable link if {@link ICrossLabelProps.onPressUrlTarget} is supplied.
 *
 * Link color can also be specified through {@link ICrossLabelProps.linkColor}.
 *
 * Properties are {@link ICrossLabelProps}
 *
 * @param param0 {@link ICrossLabelProps}
 * @returns {@link View}
 */
export declare class CrossLabel extends React.Component<ICrossLabelProps> {
    constructor(props: ICrossLabelProps);
    render(): JSX.Element;
}
export default CrossLabel;
//# sourceMappingURL=CrossLabel.d.ts.map